package de.limited_dev.lil_judd;

import de.limited_dev.lil_judd.commands.components.CommandManager;
import de.limited_dev.lil_judd.features.TimePlanner;
import de.limited_dev.lil_judd.features.storage.GuildTimePlannerStorage;
import de.limited_dev.lil_judd.listeners.GuildStateListener;
import de.limited_dev.lil_judd.listeners.ReadyListener;
import de.limited_dev.lil_judd.listeners.SlashCommandInteractionListener;
import de.limited_dev.lil_judd.util.Logger;
import de.limited_dev.lil_judd.util.SlashCommandHelper;
import de.limited_dev.lil_judd.util.managers.TokenManager;
import net.dv8tion.jda.api.JDA;
import net.dv8tion.jda.api.JDABuilder;
import net.dv8tion.jda.api.OnlineStatus;
import net.dv8tion.jda.api.entities.Activity;
import net.dv8tion.jda.api.entities.Guild;
import net.dv8tion.jda.api.interactions.commands.build.Commands;

public class Main {
    private static JDA jda;
    private static Logger lgr = new Logger();
    private static final TokenManager tokenManager = TokenManager.getInstance();
    private static long launchTime;

    public static void main(String[] args){
        lgr.info("li'l Judd is waking up ...");

        launchTime = System.currentTimeMillis();

        tokenManager.load();


        jda = JDABuilder.createDefault(tokenManager.getToken())
                .setActivity(Activity.watching("You"))
                .setStatus(OnlineStatus.DO_NOT_DISTURB)
                .build();

        CommandManager.registerCommands();

        jda.addEventListener(new ReadyListener());
        jda.addEventListener(new SlashCommandInteractionListener());
        jda.addEventListener(new GuildStateListener());


        GuildTimePlannerStorage.getInstance().load();
        TimePlanner.registerMessageThread();

        try {
            jda.awaitReady();
        } catch (InterruptedException e) {
            throw new RuntimeException(e);
        }
    }

    public static JDA getJda() {
        return jda;
    }

    public static Logger getLgr() {
        return lgr;
    }

    public static long getLaunchTime() {
        return launchTime;
    }
}
